pub struct IterativeImputer<F> { /* private fields */ }Expand description
An unfitted iterative imputer.
Calling Fit::fit learns the imputation model and returns a
FittedIterativeImputer that can impute missing values in new data.
Parameters
max_iter— maximum number of imputation rounds (default 10).tol— convergence tolerance on the total change in imputed values (default 1e-3).initial_strategy— strategy for the initial fill (defaultMean).
Examples
use ferrolearn_preprocess::iterative_imputer::{IterativeImputer, InitialStrategy};
use ferrolearn_core::traits::{Fit, Transform};
use ndarray::array;
let imputer = IterativeImputer::<f64>::new(10, 1e-3, InitialStrategy::Mean);
let x = array![[1.0, 2.0], [3.0, f64::NAN], [f64::NAN, 6.0]];
let fitted = imputer.fit(&x, &()).unwrap();
let out = fitted.transform(&x).unwrap();
assert!(!out[[1, 1]].is_nan());
assert!(!out[[2, 0]].is_nan());Implementations
Sourceimpl<F: Float + Send + Sync + 'static> IterativeImputer<F>
impl<F: Float + Send + Sync + 'static> IterativeImputer<F>
Sourcepub fn new(max_iter: usize, tol: F, initial_strategy: InitialStrategy) -> Self
pub fn new(max_iter: usize, tol: F, initial_strategy: InitialStrategy) -> Self
Create a new IterativeImputer with the given parameters.
Sourcepub fn initial_strategy(&self) -> InitialStrategy
pub fn initial_strategy(&self) -> InitialStrategy
Return the initial imputation strategy.