pub struct QuantileTransformer<F> { /* private fields */ }Expand description
An unfitted quantile transformer.
Calling Fit::fit computes the quantiles for each feature and returns a
FittedQuantileTransformer.
Parameters
n_quantiles— number of quantile reference points (default 1000).output_distribution— target distribution (defaultUniform).subsample— maximum number of samples used to compute quantiles (default 100_000; set to 0 to use all samples).
Examples
use ferrolearn_preprocess::quantile_transformer::{QuantileTransformer, OutputDistribution};
use ferrolearn_core::traits::{Fit, Transform};
use ndarray::array;
let qt = QuantileTransformer::<f64>::new(100, OutputDistribution::Uniform, 0);
let x = array![[1.0], [2.0], [3.0], [4.0], [5.0]];
let fitted = qt.fit(&x, &()).unwrap();
let out = fitted.transform(&x).unwrap();
// Values should be in [0, 1]
for v in out.iter() {
assert!(*v >= 0.0 && *v <= 1.0);
}Implementations
Sourceimpl<F: Float + Send + Sync + 'static> QuantileTransformer<F>
impl<F: Float + Send + Sync + 'static> QuantileTransformer<F>
Sourcepub fn new(
n_quantiles: usize,
output_distribution: OutputDistribution,
subsample: usize,
) -> Self
pub fn new( n_quantiles: usize, output_distribution: OutputDistribution, subsample: usize, ) -> Self
Create a new QuantileTransformer.
Sourcepub fn n_quantiles(&self) -> usize
pub fn n_quantiles(&self) -> usize
Return the number of quantiles.
Sourcepub fn output_distribution(&self) -> OutputDistribution
pub fn output_distribution(&self) -> OutputDistribution
Return the target output distribution.