pub enum Direction {
Forward,
Backward,
}Expand description
Search direction for SequentialFeatureSelector.
Variants
Forward
Start with no features and greedily add one at a time.
Backward
Start with all features and greedily remove one at a time.