pub struct ColumnTransformer { /* private fields */ }Expand description
An unfitted column transformer.
Applies each registered transformer to its designated column subset, then
horizontally concatenates all outputs. The Remainder policy controls
what happens to columns not covered by any transformer.
Transformer order
Transformers are applied and their outputs concatenated in the order they
were registered. Remainder columns (when
remainder = Remainder::Passthrough) are appended last.
Overlapping selections
Each transformer receives its own copy of the selected columns, so
overlapping ColumnSelectors are fully supported.
Examples
use ferrolearn_preprocess::column_transformer::{
ColumnSelector, ColumnTransformer, Remainder,
};
use ferrolearn_preprocess::StandardScaler;
use ferrolearn_core::Fit;
use ferrolearn_core::Transform;
use ndarray::array;
let x = array![[1.0_f64, 10.0, 100.0], [2.0, 20.0, 200.0], [3.0, 30.0, 300.0]];
let ct = ColumnTransformer::new(
vec![("scaler".into(), Box::new(StandardScaler::<f64>::new()), ColumnSelector::Indices(vec![0, 1]))],
Remainder::Passthrough,
);
let fitted = ct.fit(&x, &()).unwrap();
let out = fitted.transform(&x).unwrap();
// 2 scaled columns + 1 passthrough column
assert_eq!(out.ncols(), 3);Implementations
Sourceimpl ColumnTransformer
impl ColumnTransformer
Sourcepub fn new(
transformers: Vec<(String, Box<dyn PipelineTransformer<f64>>, ColumnSelector)>,
remainder: Remainder,
) -> Self
pub fn new( transformers: Vec<(String, Box<dyn PipelineTransformer<f64>>, ColumnSelector)>, remainder: Remainder, ) -> Self
Create a new ColumnTransformer.
Parameters
transformers: A list of(name, transformer, selector)triples.remainder: Policy for uncovered columns (DroporPassthrough).