Module function_transformer

Module function_transformer 

Function transformer: apply a user-provided function element-wise.

Wraps any Fn(F) -> F callable and applies it to every element in the input matrix. This is useful for applying non-standard transformations such as ln, sqrt, or custom domain-specific functions.

This transformer is stateless — no fitting is required. Call Transform::transform directly.

Structs

FunctionTransformer
A stateless element-wise function transformer.