pub struct SimpleImputer<F> { /* private fields */ }Expand description
An unfitted simple imputer.
Calling Fit::fit computes the per-column fill values according to
the chosen ImputeStrategy and returns a FittedSimpleImputer that
can transform new data by replacing NaN values with those fill values.
NaN values are ignored when computing statistics during fitting — e.g.
the Mean strategy computes the mean of only the non-NaN elements.
Examples
use ferrolearn_preprocess::imputer::{SimpleImputer, ImputeStrategy};
use ferrolearn_core::traits::{Fit, Transform};
use ndarray::array;
let imputer = SimpleImputer::<f64>::new(ImputeStrategy::Mean);
let x = array![[1.0, f64::NAN], [3.0, 4.0], [5.0, 6.0]];
let fitted = imputer.fit(&x, &()).unwrap();
let out = fitted.transform(&x).unwrap();
// NaN in column 1 row 0 is replaced with the mean of column 1 = (4+6)/2 = 5.0
assert!((out[[0, 1]] - 5.0).abs() < 1e-10);Implementations
Sourceimpl<F: Float + Send + Sync + 'static> SimpleImputer<F>
impl<F: Float + Send + Sync + 'static> SimpleImputer<F>
Sourcepub fn new(strategy: ImputeStrategy<F>) -> Self
pub fn new(strategy: ImputeStrategy<F>) -> Self
Create a new SimpleImputer with the given strategy.
Sourcepub fn strategy(&self) -> &ImputeStrategy<F>
pub fn strategy(&self) -> &ImputeStrategy<F>
Return the imputation strategy.